/*
 * Handles Prolog facts (e.g., "child_of(bob,carrie)").
 */

package checkpolicy.prolog;

public class Fact
{
    
    // Attributes
    private String functor = "";
    private String[] arguments = null;
    
    // Accessors
    public String getFunctor()
    {
        return functor;
    }

    public void setFunctor(String functor)
    {
        this.functor = functor;
    }

    public String[] getArguments()
    {
        return arguments;
    }

    public void setArguments(String[] arguments)
    {
        this.arguments = arguments;
    }
    
    // Constructor
    /**
     * Constructs a new Fact object with the appropriate functor and args list.
     * @param functor The name of the functor.
     * @param args The list of arguments (null means empty).
     */
    public Fact(String functor, String[] args)
    {
        this.functor = functor;
        this.arguments = args;
    }
    
    // Methods
    /**
     * Outputs the fact as a "\n"-terminated string of Prolog code.
     * @return A line of Prolog code containing the fact.
     */
    public String toString()
    {
        StringBuilder code = new StringBuilder();
        code.append(functor);
        code.append("(");
        if (arguments != null)
        {
            for (int i = 0; i < arguments.length; i++)
            {
                code.append(arguments[i]);
                if (i < arguments.length-1)
                    code.append(",");
            }
        }
        code.append(").\n");
        return code.toString();
    }

}
